## Download
`pip install youtube-lv`  
[download ChromeDriver](https://chromedriver.chromium.org/)

## Use
```python
    import ch_anime
    sp=ch_anime.spyder()
    output=sp.agefans(data)
    print(output)
```

## other
```python
    sp=ch_anime.spyder()
    sp.agefans
    sp.anime1
    sp.youtube_search
    sp.translate
    sp.removebg
    sp.schimage
    sp.yandere
    sp.konachan
    sp.danbooru
```
